Chart App
=========

|PyPI version| |Build Status| |codecov| |Codacy Badge| |Maintainability|
|Test Coverage|

This is a web app designed to crunch data into charts ... like excel ^^'

Demo
----

You can have a demo available at
`localhost:5001 <http://127.0.0.1:5001/>`__

.. code:: bash

    python charpy/app.py

.. |PyPI version| image:: https://badge.fury.io/py/charpy.svg
   :target: https://badge.fury.io/py/charpy
.. |Build Status| image:: https://travis-ci.org/Sylhare/charpy.svg?branch=master
   :target: https://travis-ci.org/Sylhare/charpy
.. |codecov| image:: https://codecov.io/gh/Sylhare/charpy/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/Sylhare/charpy
.. |Codacy Badge| image:: https://api.codacy.com/project/badge/Grade/7ecd2366da08459aa8c7af9c489dc65c
   :target: https://www.codacy.com/app/Sylhare/charpy?utm_source=github.com&utm_medium=referral&utm_content=Sylhare/charpy&utm_campaign=Badge_Grade
.. |Maintainability| image:: https://api.codeclimate.com/v1/badges/ad17a7f76d6421c83b61/maintainability
   :target: https://codeclimate.com/github/Sylhare/charpy/maintainability
.. |Test Coverage| image:: https://api.codeclimate.com/v1/badges/ad17a7f76d6421c83b61/test_coverage
   :target: https://codeclimate.com/github/Sylhare/charpy/test_coverage
